summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/dungeon.cc
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2009-10-06 15:40:04 +0200
committerAdam Borowski <kilobyte@angband.pl>2009-10-06 15:40:04 +0200
commit35bb2fd5f7327ea0f4521ec3d7501064f9e24e7b (patch)
tree02ed1e0b5be6374c3f13b7ca64254f12113acdc1 /crawl-ref/source/dungeon.cc
parentc591003b88f95795178a2de89ec9cb0845f84a0a (diff)
downloadcrawl-ref-35bb2fd5f7327ea0f4521ec3d7501064f9e24e7b.tar.gz
crawl-ref-35bb2fd5f7327ea0f4521ec3d7501064f9e24e7b.zip
Give Khufu a quote (due), make him spawn in Tomb and Crypt.
Diffstat (limited to 'crawl-ref/source/dungeon.cc')
-rw-r--r--crawl-ref/source/dungeon.cc7
1 files changed, 6 insertions, 1 deletions
diff --git a/crawl-ref/source/dungeon.cc b/crawl-ref/source/dungeon.cc
index 5fe5d766ec..8f8cee0e81 100644
--- a/crawl-ref/source/dungeon.cc
+++ b/crawl-ref/source/dungeon.cc
@@ -3287,7 +3287,7 @@ static bool _make_room(int sx,int sy,int ex,int ey,int max_doors, int doorlevel)
}
// Doesn't include Polyphemus or Ilsuiw (only appear in the Shoals),
// Dissolution (Slime), Murray (Hell), or Tiamat (Zot).
// NOTE: The Lernaean hydra should *never* be randomly generated.
// The Royal jelly likewise is only placed via Slime end vault.
// Dowan is automatically placed together with Duvessa.
@@ -3387,6 +3387,11 @@ static monster_type _pick_unique(int lev)
else if (player_branch_depth() > 2 && coinflip())
which_unique = MONS_ILSUIW;
}
+ else if (player_in_branch(BRANCH_TOMB) || player_in_branch(BRANCH_CRYPT))
+ {
+ if (one_chance_in(10))
+ which_unique = MONS_KHUFU;
+ }
return static_cast<monster_type>(which_unique);
}
@@ -3287,7 +3287,7 @@ static bool _make_room(int sx,int sy,int ex,int ey,int max_doors, int doorlevel)
}
// Doesn't include Polyphemus or Ilsuiw (only appear in the Shoals),
-// Dissolution (Slime), Murray (Hell), or Tiamat (Zot).
+// Dissolution (Slime), Murray (Hell), Khufu(Tomb/Crypt) or Tiamat (Zot).
// NOTE: The Lernaean hydra should *never* be randomly generated.
// The Royal jelly likewise is only placed via Slime end vault.